<?php

namespace Drupal\Tests\migrate_conditions\Kernel;

use Drupal\KernelTests\KernelTestBase;
use Drupal\migrate\MigrateExecutable;
use Drupal\migrate\Plugin\MigrationInterface;

/**
 * Tests the ConditionPluginManager.
 *
 * @group migrate_conditions
 */
class ConditionPluginManagerTest extends KernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['migrate', 'migrate_conditions'];

  /**
   * Tests using 'not:' to negate plugins.
   */
  public function testConditionPluginManagerNot() {
    $row = $this->getMockBuilder('Drupal\migrate\Row')
      ->disableOriginalConstructor()
      ->getMock();

    // Typical scenario.
    $configuration = [
      'value' => 123,
    ];
    $condition = \Drupal::service('plugin.manager.migrate_conditions.condition')->createInstance('not:equals', $configuration);
    $this->assertTrue($condition->evaluate(234, $row));
    $this->assertFalse($condition->evaluate(123, $row));

    // Explicitly setting negate to false and using 'not:'.
    $configuration = [
      'value' => 123,
      'negate' => FALSE,
    ];
    $condition = \Drupal::service('plugin.manager.migrate_conditions.condition')->createInstance('not:equals', $configuration);
    $this->assertTrue($condition->evaluate(234, $row));
    $this->assertFalse($condition->evaluate(123, $row));

    // Two 'not:' prefixes.
    $configuration = [
      'value' => 123,
    ];
    $condition = \Drupal::service('plugin.manager.migrate_conditions.condition')->createInstance('not:not:equals', $configuration);
    $this->assertFalse($condition->evaluate(234, $row));
    $this->assertTrue($condition->evaluate(123, $row));

    // Passing 'negate' config and using 'not:'.
    $configuration = [
      'value' => 123,
      'negate' => TRUE,
    ];
    $condition = \Drupal::service('plugin.manager.migrate_conditions.condition')->createInstance('not:equals', $configuration);
    $this->assertFalse($condition->evaluate(234, $row));
    $this->assertTrue($condition->evaluate(123, $row));
  }

}
